@@ -5,8 +5,9 @@ test_dir <- file.path(tempdir(), "sdmpredictors")
 options(sdmpredictors_datadir = test_dir)
 
 check_skip <- function() {
- # skip("skip today")
+  # skip("skip today")
   skip_on_cran()
+  skip_on_travis()
 }
 
 context("Load layers")
@@ -133,6 +134,7 @@ test_that("load_layer for multiple mixed previously downloaded layers works", {
 })
 
 test_that("load_layer handles special cases", {
+  check_skip()
   expect_error(load_layers("blabla"))
   expect_error(load_layers("BO_ph", equalarea = NA))
   expect_error(load_layers(c("BO_ph", "BO_calcite"), equalarea = c(T,F)))
@@ -162,4 +164,14 @@ test_that("load_layer equal area TRUE/FALSE works", {
   is_lonlat(rs_lonlat)
 })
 
+test_that("A sample of 500 layers is available on http://www.lifewatch.be/sdmpredictors/", {
+  check_skip()
+  url <- c(list_layers()$layer_code, list_layers_future()$layer_code, list_layers_paleo()$layer_code)
+  url <- paste0("http://www.lifewatch.be/sdmpredictors/", url, ".tif")
+  url <- sample(url, 500)
+  for (url_i in url){
+      expect_true(RCurl::url.exists(url_i, useragent="https://github.com/lifewatch/sdmpredictors"))
+  }
+})
+
 unlink(load_tmp_dir, recursive=TRUE)
\ No newline at end of file
